==> estateplat-common-1.2.4-20210719.062751-815-sources.jar: cn/gtmap/estateplat/model/server/core/BdcTdjyq.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Table;
import java.util.Date;
/**
 * @author <a href="mailto:jiangganzhi@gtmap.cn">jiangganzhi</a>
 * @version V1.0, 2021/3/16
 * @description 土地经营权
 */
@Table(name = "BDC_TDJYQ")
public class BdcTdjyq extends QllxParent implements QllxVo{
    private String fj;
    private String bz;
    private String zxyy;
    private String zxdbr;
    private Date zxdbsj;
    private Date jykssj;
    private Date jyjssj;
    private String jyyt;
    private Double zbjg;
    private String jyfw;
    private Double jymj;
    private Double scmj;
    private String tdyt;
    private String qlxz;

    @Override
    public String getFj() {
        return fj;
    }

    @Override
    public void setFj(String fj) {
        this.fj = fj;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getZxyy() {
        return zxyy;
    }

    public void setZxyy(String zxyy) {
        this.zxyy = zxyy;
    }

    public String getZxdbr() {
        return zxdbr;
    }

    public void setZxdbr(String zxdbr) {
        this.zxdbr = zxdbr;
    }

    public Date getZxdbsj() {
        return zxdbsj;
    }

    public void setZxdbsj(Date zxdbsj) {
        this.zxdbsj = zxdbsj;
    }

    public Date getJykssj() {
        return jykssj;
    }

    public void setJykssj(Date jykssj) {
        this.jykssj = jykssj;
    }

    public Date getJyjssj() {
        return jyjssj;
    }

    public void setJyjssj(Date jyjssj) {
        this.jyjssj = jyjssj;
    }

    public String getJyyt() {
        return jyyt;
    }

    public void setJyyt(String jyyt) {
        this.jyyt = jyyt;
    }

    public Double getZbjg() {
        return zbjg;
    }

    public void setZbjg(Double zbjg) {
        this.zbjg = zbjg;
    }

    public String getJyfw() {
        return jyfw;
    }

    public void setJyfw(String jyfw) {
        this.jyfw = jyfw;
    }

    public Double getJymj() {
        return jymj;
    }

    public void setJymj(Double jymj) {
        this.jymj = jymj;
    }

    public Double getScmj() {
        return scmj;
    }

    public void setScmj(Double scmj) {
        this.scmj = scmj;
    }

    public String getTdyt() {
        return tdyt;
    }

    public void setTdyt(String tdyt) {
        this.tdyt = tdyt;
    }

    public String getQlxz() {
        return qlxz;
    }

    public void setQlxz(String qlxz) {
        this.qlxz = qlxz;
    }
}

==> estateplat-common-1.2.4-20220523.022612-1026-sources.jar: cn/gtmap/estateplat/model/server/core/BdcTdjyq.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Table;
import java.util.Date;
/**
 * @author <a href="mailto:jiangganzhi@gtmap.cn">jiangganzhi</a>
 * @version V1.0, 2021/3/16
 * @description 土地经营权
 */
@Table(name = "BDC_TDJYQ")
public class BdcTdjyq extends QllxParent implements QllxVo{
    private String fj;
    private String bz;
    private String zxyy;
    private String zxdbr;
    private Date zxdbsj;
    private Date jykssj;
    private Date jyjssj;
    private String jyyt;
    private Double zbjg;
    private String jyfw;
    private Double jymj;
    private Double scmj;
    private String tdyt;
    private String qlxz;

    private String fbfdm ;//发包方代码
    private String cbhtbm ;//承包合同代码
    private String ydyhfl ;//用地用海分类
    private String tdcbht ;//土地承包合同

    public String getFbfdm() {
        return fbfdm;
    }

    public void setFbfdm(String fbfdm) {
        this.fbfdm = fbfdm;
    }

    public String getCbhtbm() {
        return cbhtbm;
    }

    public void setCbhtbm(String cbhtbm) {
        this.cbhtbm = cbhtbm;
    }

    public String getYdyhfl() {
        return ydyhfl;
    }

    public void setYdyhfl(String ydyhfl) {
        this.ydyhfl = ydyhfl;
    }

    public String getTdcbht() {
        return tdcbht;
    }

    public void setTdcbht(String tdcbht) {
        this.tdcbht = tdcbht;
    }

    @Override
    public String getFj() {
        return fj;
    }

    @Override
    public void setFj(String fj) {
        this.fj = fj;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getZxyy() {
        return zxyy;
    }

    public void setZxyy(String zxyy) {
        this.zxyy = zxyy;
    }

    public String getZxdbr() {
        return zxdbr;
    }

    public void setZxdbr(String zxdbr) {
        this.zxdbr = zxdbr;
    }

    public Date getZxdbsj() {
        return zxdbsj;
    }

    public void setZxdbsj(Date zxdbsj) {
        this.zxdbsj = zxdbsj;
    }

    public Date getJykssj() {
        return jykssj;
    }

    public void setJykssj(Date jykssj) {
        this.jykssj = jykssj;
    }

    public Date getJyjssj() {
        return jyjssj;
    }

    public void setJyjssj(Date jyjssj) {
        this.jyjssj = jyjssj;
    }

    public String getJyyt() {
        return jyyt;
    }

    public void setJyyt(String jyyt) {
        this.jyyt = jyyt;
    }

    public Double getZbjg() {
        return zbjg;
    }

    public void setZbjg(Double zbjg) {
        this.zbjg = zbjg;
    }

    public String getJyfw() {
        return jyfw;
    }

    public void setJyfw(String jyfw) {
        this.jyfw = jyfw;
    }

    public Double getJymj() {
        return jymj;
    }

    public void setJymj(Double jymj) {
        this.jymj = jymj;
    }

    public Double getScmj() {
        return scmj;
    }

    public void setScmj(Double scmj) {
        this.scmj = scmj;
    }

    public String getTdyt() {
        return tdyt;
    }

    public void setTdyt(String tdyt) {
        this.tdyt = tdyt;
    }

    public String getQlxz() {
        return qlxz;
    }

    public void setQlxz(String qlxz) {
        this.qlxz = qlxz;
    }
}
